@@ -158,3 +158,17 @@ acb_sqrt(acb_t y, const acb_t x, slong prec)
 #undef d
 }
 
+void
+acb_sqrt_analytic(acb_ptr res, const acb_t z, int analytic, slong prec)
+{
+    if (analytic && arb_contains_zero(acb_imagref(z)) &&
+        !arb_is_positive(acb_realref(z)))
+    {
+        acb_indeterminate(res);
+    }
+    else
+    {
+        acb_sqrt(res, z, prec);
+    }
+}
+
