@@ -21,7 +21,7 @@ acb_dirichlet_zeta_zeros(acb_ptr res, const fmpz_t n, slong len, slong prec)
     }
     else if (fmpz_sgn(n) < 1)
     {
-        flint_printf("nonpositive indices of zeros are not supported\n");
+        flint_printf("nonpositive indices of zeta zeros are not supported\n");
         flint_abort();
     }
     else
