@@ -10,12 +10,14 @@
 */
 
 #include "acb_hypgeom.h"
+#include "arb_hypgeom.h"
 
 void
 acb_hypgeom_legendre_p(acb_t res, const acb_t n, const acb_t m,
     const acb_t z, int type, slong prec)
 {
     acb_t a, b, c, w;
+    int flag;
 
     if (!acb_is_finite(z))
     {
@@ -23,6 +25,16 @@ acb_hypgeom_legendre_p(acb_t res, const acb_t n, const acb_t m,
         return;
     }
 
+    if (acb_is_real(z) && acb_is_zero(m) && acb_is_int(n) &&
+        arf_sgn(arb_midref(acb_realref(n))) >= 0 &&
+        arf_cmpabs_2exp_si(arb_midref(acb_realref(n)), FLINT_BITS - 1) < 0)
+    {
+        arb_hypgeom_legendre_p_ui(acb_realref(res), NULL,
+            arf_get_si(arb_midref(acb_realref(n)), ARF_RND_DOWN), acb_realref(z), prec);
+        arb_zero(acb_imagref(res));
+        return;
+    }
+
     if (acb_is_int(n) && acb_is_int(m) && arb_is_nonnegative(acb_realref(n))
         && arb_is_nonnegative(acb_realref(m)) && type == 0)
     {
@@ -91,7 +103,13 @@ acb_hypgeom_legendre_p(acb_t res, const acb_t n, const acb_t m,
     acb_neg(w, w);
     acb_mul_2exp_si(w, w, -1);
 
-    acb_hypgeom_2f1(w, a, b, c, w, 1, prec);
+    /* a + b - c (which could be inexact) is integer iff c is integer */
+    flag = 1;
+    if (acb_is_int(c))
+    {
+        flag |= ACB_HYPGEOM_2F1_ABC;
+    }
+    acb_hypgeom_2f1(w, a, b, c, w, flag, prec);
 
     if (!acb_is_zero(m))
     {
