@@ -9,6 +9,7 @@
     (at your option) any later version.  See <http://www.gnu.org/licenses/>.
 */
 
+#include "arb_hypgeom.h"
 #include "acb_hypgeom.h"
 
 void
@@ -122,9 +123,15 @@ acb_hypgeom_si_1f2(acb_t res, const acb_t z, slong prec)
 void
 acb_hypgeom_si(acb_t res, const acb_t z, slong prec)
 {
+    if (acb_is_real(z) && arb_is_finite(acb_realref(z)))
+    {
+        arb_hypgeom_si(acb_realref(res), acb_realref(z), prec);
+        arb_zero(acb_imagref(res));
+        return;
+    }
+
     if (acb_hypgeom_u_use_asymp(z, prec))
         acb_hypgeom_si_asymp(res, z, prec);
     else
         acb_hypgeom_si_1f2(res, z, prec);
 }
-
