@@ -27,9 +27,9 @@ extern "C" {
 #endif
 
 #define __ARB_VERSION 2
-#define __ARB_VERSION_MINOR 19
-#define __ARB_VERSION_PATCHLEVEL 0
-#define ARB_VERSION "2.19.0"
+#define __ARB_VERSION_MINOR 22
+#define __ARB_VERSION_PATCHLEVEL 1
+#define ARB_VERSION "2.22.1"
 #define __ARB_RELEASE (__ARB_VERSION * 10000 + \
                          __ARB_VERSION_MINOR * 100 + \
                          __ARB_VERSION_PATCHLEVEL)
@@ -333,6 +333,8 @@ void arb_randtest(arb_t x, flint_rand_t state, slong prec, slong mag_bits);
 
 void arb_randtest_special(arb_t x, flint_rand_t state, slong prec, slong mag_bits);
 
+void arb_urandom(arb_t x, flint_rand_t state, slong prec);
+
 void arb_add_error_arf(arb_t x, const arf_t err);
 
 void arb_add_error_2exp_si(arb_t x, slong err);
@@ -423,6 +425,12 @@ void arb_submul_si(arb_t z, const arb_t x, slong y, slong prec);
 void arb_submul_ui(arb_t z, const arb_t x, ulong y, slong prec);
 void arb_submul_fmpz(arb_t z, const arb_t x, const fmpz_t y, slong prec);
 
+void arb_fma(arb_t res, const arb_t x, const arb_t y, const arb_t z, slong prec);
+void arb_fma_arf(arb_t res, const arb_t x, const arf_t y, const arb_t z, slong prec);
+void arb_fma_si(arb_t res, const arb_t x, slong y, const arb_t z, slong prec);
+void arb_fma_ui(arb_t res, const arb_t x, ulong y, const arb_t z, slong prec);
+void arb_fma_fmpz(arb_t res, const arb_t x, const fmpz_t y, const arb_t z, slong prec);
+
 void arb_dot_simple(arb_t res, const arb_t initial, int subtract,
     arb_srcptr x, slong xstep, arb_srcptr y, slong ystep, slong len, slong prec);
 void arb_dot_precise(arb_t res, const arb_t initial, int subtract,
@@ -433,6 +441,17 @@ void arb_dot(arb_t res, const arb_t initial, int subtract,
 void arb_approx_dot(arb_t res, const arb_t initial, int subtract,
     arb_srcptr x, slong xstep, arb_srcptr y, slong ystep, slong len, slong prec);
 
+void arb_dot_ui(arb_t res, const arb_t initial, int subtract,
+    arb_srcptr x, slong xstep, const ulong * y, slong ystep, slong len, slong prec);
+void arb_dot_si(arb_t res, const arb_t initial, int subtract,
+    arb_srcptr x, slong xstep, const slong * y, slong ystep, slong len, slong prec);
+void arb_dot_uiui(arb_t res, const arb_t initial, int subtract,
+    arb_srcptr x, slong xstep, const ulong * y, slong ystep, slong len, slong prec);
+void arb_dot_siui(arb_t res, const arb_t initial, int subtract,
+    arb_srcptr x, slong xstep, const ulong * y, slong ystep, slong len, slong prec);
+void arb_dot_fmpz(arb_t res, const arb_t initial, int subtract,
+    arb_srcptr x, slong xstep, const fmpz * y, slong ystep, slong len, slong prec);
+
 void arb_div(arb_t z, const arb_t x, const arb_t y, slong prec);
 void arb_div_arf(arb_t z, const arb_t x, const arf_t y, slong prec);
 void arb_div_si(arb_t z, const arb_t x, slong y, slong prec);
@@ -550,15 +569,9 @@ void arb_digamma(arb_t y, const arb_t x, slong prec);
 void arb_zeta(arb_t z, const arb_t s, slong prec);
 void arb_hurwitz_zeta(arb_t z, const arb_t s, const arb_t a, slong prec);
 
-void arb_rising_ui_bs(arb_t y, const arb_t x, ulong n, slong prec);
-void arb_rising_ui_rs(arb_t y, const arb_t x, ulong n, ulong m, slong prec);
-void arb_rising_ui_rec(arb_t y, const arb_t x, ulong n, slong prec);
 void arb_rising_ui(arb_t z, const arb_t x, ulong n, slong prec);
 void arb_rising_fmpq_ui(arb_t y, const fmpq_t x, ulong n, slong prec);
 void arb_rising(arb_t z, const arb_t x, const arb_t n, slong prec);
-
-void arb_rising2_ui_rs(arb_t u, arb_t v, const arb_t x, ulong n, ulong m, slong prec);
-void arb_rising2_ui_bs(arb_t u, arb_t v, const arb_t x, ulong n, slong prec);
 void arb_rising2_ui(arb_t u, arb_t v, const arb_t x, ulong n, slong prec);
 
 void arb_log_ui_from_prev(arb_t s, ulong k, arb_t log_prev, ulong prev, slong prec);
@@ -596,10 +609,15 @@ void arb_bell_ui(arb_t res, ulong n, slong prec);
 
 void arb_euler_number_fmpz(arb_t res, const fmpz_t n, slong prec);
 void arb_euler_number_ui(arb_t res, ulong n, slong prec);
+void arb_fmpz_euler_number_ui_multi_mod(fmpz_t res, ulong n, double alpha);
+void arb_fmpz_euler_number_ui(fmpz_t res, ulong n);
 
 void arb_partitions_fmpz(arb_t res, const fmpz_t n, slong prec);
 void arb_partitions_ui(arb_t res, ulong n, slong prec);
 
+void arb_primorial_nth_ui(arb_t res, ulong n, slong prec);
+void arb_primorial_ui(arb_t res, ulong n, slong prec);
+
 void arb_lambertw(arb_t res, const arb_t x, int flags, slong prec);
 
 ARB_INLINE void
@@ -639,6 +657,18 @@ _arb_vec_entry_ptr(arb_ptr vec, slong i)
     return vec + i;
 }
 
+ARB_INLINE void
+_arb_vec_printn(arb_srcptr vec, slong len, slong ndigits, ulong flags)
+{
+    slong i;
+    for (i = 0; i < len; i++)
+    {
+        arb_printn(vec + i, ndigits, flags);
+        if (i < len - 1)
+            flint_printf(", ");
+    }
+}
+
 ARB_INLINE void
 _arb_vec_zero(arb_ptr A, slong n)
 {
