@@ -1,27 +1,13 @@
-/*=============================================================================
-
-    This file is part of ARB.
-
-    ARB is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    ARB is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with ARB; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
+/*
     Copyright (C) 2014 Fredrik Johansson
 
-******************************************************************************/
+    This file is part of Arb.
+
+    Arb is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #include "arb.h"
 
@@ -34,7 +20,7 @@
 
 #if FLINT_BITS == 64
 
-const mp_limb_t factorial_tab_numer[FACTORIAL_TAB_SIZE] = {
+ARB_DLL const mp_limb_t factorial_tab_numer[FACTORIAL_TAB_SIZE] = {
     UWORD(2432902008176640000),
     UWORD(2432902008176640000),
     UWORD(1216451004088320000),
@@ -325,7 +311,7 @@ const mp_limb_t factorial_tab_numer[FACTORIAL_TAB_SIZE] = {
     UWORD(1),
 };
 
-const mp_limb_t factorial_tab_denom[FACTORIAL_TAB_SIZE] = {
+ARB_DLL const mp_limb_t factorial_tab_denom[FACTORIAL_TAB_SIZE] = {
     UWORD(2432902008176640000),
     UWORD(2432902008176640000),
     UWORD(2432902008176640000),
@@ -618,7 +604,7 @@ const mp_limb_t factorial_tab_denom[FACTORIAL_TAB_SIZE] = {
 
 #else
 
-const mp_limb_t factorial_tab_numer[FACTORIAL_TAB_SIZE] = {
+ARB_DLL const mp_limb_t factorial_tab_numer[FACTORIAL_TAB_SIZE] = {
     UWORD(479001600),
     UWORD(479001600),
     UWORD(239500800),
@@ -909,7 +895,7 @@ const mp_limb_t factorial_tab_numer[FACTORIAL_TAB_SIZE] = {
     UWORD(288),
 };
 
-const mp_limb_t factorial_tab_denom[FACTORIAL_TAB_SIZE] = {
+ARB_DLL const mp_limb_t factorial_tab_denom[FACTORIAL_TAB_SIZE] = {
     UWORD(479001600),
     UWORD(479001600),
     UWORD(479001600),
@@ -1215,7 +1201,7 @@ void _arb_exp_taylor_rs(mp_ptr y, mp_limb_t * error,
     if (N >= FACTORIAL_TAB_SIZE - 1)
     {
         flint_printf("_arb_exp_taylor_rs: N too large!\n");
-        abort();
+        flint_abort();
     }
 
     if (N <= 3)
