@@ -24,7 +24,7 @@ int main()
     for (iter = 0; iter < 10000 * arb_test_multiplier(); iter++)
     {
         arb_t a, b, c, d;
-        slong prec;
+        slong prec, acc1, acc2;
 
         if (iter % 10 == 0)
             prec = 10000;
@@ -42,30 +42,51 @@ int main()
         arb_randtest_special(b, state, 1 + n_randint(state, prec), 1 + n_randint(state, 100));
         arb_randtest_special(c, state, 1 + n_randint(state, prec), 1 + n_randint(state, 100));
 
-        arb_exp_invexp(b, c, a, prec);
+        if (n_randint(state, 2))
+        {
+            arb_exp_invexp(b, c, a, prec);
+        }
+        else if (n_randint(state, 2))
+        {
+            arb_set(b, a);
+            arb_exp_invexp(b, c, b, prec);
+        }
+        else
+        {
+            arb_set(c, a);
+            arb_exp_invexp(b, c, c, prec);
+        }
 
         arb_exp(d, a, prec);
 
-        if (!arb_overlaps(b, d))
+        acc1 = arb_rel_accuracy_bits(b);
+        acc2 = arb_rel_accuracy_bits(d);
+
+        if (!arb_overlaps(b, d) || ((acc1 > 0 || acc2 > 0) && acc1 < FLINT_MIN(acc2, prec) - 3))
         {
             flint_printf("FAIL: overlap 1\n\n");
+            flint_printf("prec = %wd, acc1 = %wd, acc2 = %wd\n\n", prec, acc1, acc2);
             flint_printf("a = "); arb_print(a); flint_printf("\n\n");
             flint_printf("b = "); arb_print(b); flint_printf("\n\n");
             flint_printf("c = "); arb_print(c); flint_printf("\n\n");
-            flint_printf("d = "); arb_print(c); flint_printf("\n\n");
+            flint_printf("d = "); arb_print(d); flint_printf("\n\n");
             flint_abort();
         }
 
         arb_neg(d, a);
         arb_exp(d, d, prec);
 
-        if (!arb_overlaps(c, d))
+        acc1 = arb_rel_accuracy_bits(c);
+        acc2 = arb_rel_accuracy_bits(d);
+
+        if (!arb_overlaps(c, d) || ((acc1 > 0 || acc2 > 0) && acc1 < FLINT_MIN(acc2, prec) - 3))
         {
             flint_printf("FAIL: overlap 2\n\n");
+            flint_printf("prec = %wd, acc1 = %wd, acc2 = %wd\n\n", prec, acc1, acc2);
             flint_printf("a = "); arb_print(a); flint_printf("\n\n");
             flint_printf("b = "); arb_print(b); flint_printf("\n\n");
             flint_printf("c = "); arb_print(c); flint_printf("\n\n");
-            flint_printf("d = "); arb_print(c); flint_printf("\n\n");
+            flint_printf("d = "); arb_print(d); flint_printf("\n\n");
             flint_abort();
         }
 
@@ -80,4 +101,3 @@ int main()
     flint_printf("PASS\n");
     return EXIT_SUCCESS;
 }
-
