@@ -12,42 +12,6 @@
 #include "arb_hypgeom.h"
 #include "acb_hypgeom.h"
 
-void
-arb_hypgeom_erf(arb_t res, const arb_t z, slong prec)
-{
-    if (!arb_is_finite(z))
-    {
-        arb_indeterminate(res);
-    }
-    else
-    {
-        acb_t t;
-        acb_init(t);
-        arb_set(acb_realref(t), z);
-        acb_hypgeom_erf(t, t, prec);
-        arb_swap(res, acb_realref(t));
-        acb_clear(t);
-    }
-}
-
-void
-arb_hypgeom_erfc(arb_t res, const arb_t z, slong prec)
-{
-    if (!arb_is_finite(z))
-    {
-        arb_indeterminate(res);
-    }
-    else
-    {
-        acb_t t;
-        acb_init(t);
-        arb_set(acb_realref(t), z);
-        acb_hypgeom_erfc(t, t, prec);
-        arb_swap(res, acb_realref(t));
-        acb_clear(t);
-    }
-}
-
 void
 arb_hypgeom_erfi(arb_t res, const arb_t z, slong prec)
 {
@@ -106,42 +70,6 @@ arb_hypgeom_ei(arb_t res, const arb_t z, slong prec)
     }
 }
 
-void
-arb_hypgeom_si(arb_t res, const arb_t z, slong prec)
-{
-    if (!arb_is_finite(z))
-    {
-        arb_indeterminate(res);
-    }
-    else
-    {
-        acb_t t;
-        acb_init(t);
-        arb_set(acb_realref(t), z);
-        acb_hypgeom_si(t, t, prec);
-        arb_swap(res, acb_realref(t));
-        acb_clear(t);
-    }
-}
-
-void
-arb_hypgeom_ci(arb_t res, const arb_t z, slong prec)
-{
-    if (!arb_is_finite(z) || !arb_is_positive(z))
-    {
-        arb_indeterminate(res);
-    }
-    else
-    {
-        acb_t t;
-        acb_init(t);
-        arb_set(acb_realref(t), z);
-        acb_hypgeom_ci(t, t, prec);
-        arb_swap(res, acb_realref(t));
-        acb_clear(t);
-    }
-}
-
 void
 arb_hypgeom_shi(arb_t res, const arb_t z, slong prec)
 {
@@ -629,3 +557,16 @@ arb_hypgeom_legendre_q(arb_t res, const arb_t n, const arb_t m, const arb_t z, i
     acb_clear(v);
 }
 
+void
+arb_hypgeom_dilog(arb_t res, const arb_t z, slong prec)
+{
+    acb_t t;
+    acb_init(t);
+    arb_set(acb_realref(t), z);
+    acb_hypgeom_dilog(t, t, prec);
+    if (acb_is_finite(t) && acb_is_real(t))
+        arb_swap(res, acb_realref(t));
+    else
+        arb_indeterminate(res);
+    acb_clear(t);
+}
