@@ -105,7 +105,7 @@ arf_rnd_to_mpfr(arf_rnd_t rnd)
 #define ARF_XSIZE(x) ((x)->size)
 
 /* Construct size field value from size in limbs and sign bit. */
-#define ARF_MAKE_XSIZE(size, sgnbit) ((((mp_size_t) size) << 1) | sgnbit)
+#define ARF_MAKE_XSIZE(size, sgnbit) ((((mp_size_t) size) << 1) | (sgnbit))
 
 /* The limb size, and the sign bit. */
 #define ARF_SIZE(x) (ARF_XSIZE(x) >> 1)
@@ -610,8 +610,9 @@ int arf_get_mpfr(mpfr_t x, const arf_t y, mpfr_rnd_t rnd);
 void arf_set_mpfr(arf_t x, const mpfr_t y);
 
 int arf_equal(const arf_t x, const arf_t y);
-
 int arf_equal_si(const arf_t x, slong y);
+int arf_equal_ui(const arf_t x, ulong y);
+int arf_equal_d(const arf_t x, double y);
 
 ARF_INLINE void
 arf_min(arf_t z, const arf_t a, const arf_t b)
@@ -775,6 +776,8 @@ void arf_ceil(arf_t z, const arf_t x);
 
 void arf_debug(const arf_t x);
 
+char * arf_get_str(const arf_t x, slong d);
+
 void arf_fprint(FILE * file, const arf_t x);
 
 void arf_fprintd(FILE * file, const arf_t y, slong d);
@@ -797,6 +800,8 @@ void arf_randtest_not_zero(arf_t x, flint_rand_t state, slong bits, slong mag_bi
 
 void arf_randtest_special(arf_t x, flint_rand_t state, slong bits, slong mag_bits);
 
+void arf_urandom(arf_t x, flint_rand_t state, slong bits, arf_rnd_t rnd);
+
 #define MUL_MPFR_MIN_LIMBS 25
 #define MUL_MPFR_MAX_LIMBS 10000
 
@@ -997,7 +1002,7 @@ ARB_DLL extern void _arf_add_tmp_cleanup(void);
 
 int _arf_add_mpn(arf_t z, mp_srcptr xp, mp_size_t xn, int xsgnbit,
     const fmpz_t xexp, mp_srcptr yp, mp_size_t yn, int ysgnbit,
-    mp_bitcnt_t shift, slong prec, arf_rnd_t rnd);
+    flint_bitcnt_t shift, slong prec, arf_rnd_t rnd);
 
 int arf_add(arf_ptr z, arf_srcptr x, arf_srcptr y, slong prec, arf_rnd_t rnd);
 int arf_add_si(arf_ptr z, arf_srcptr x, slong y, slong prec, arf_rnd_t rnd);
@@ -1069,6 +1074,8 @@ arf_submul_fmpz(arf_ptr z, arf_srcptr x, const fmpz_t y, slong prec, arf_rnd_t r
         return arf_submul_mpz(z, x, COEFF_TO_PTR(*y), prec, rnd);
 }
 
+int arf_fma(arf_ptr res, arf_srcptr x, arf_srcptr y, arf_srcptr z, slong prec, arf_rnd_t rnd);
+
 int arf_sosq(arf_t z, const arf_t x, const arf_t y, slong prec, arf_rnd_t rnd);
 
 int arf_div(arf_ptr z, arf_srcptr x, arf_srcptr y, slong prec, arf_rnd_t rnd);
